@@ -81,7 +81,7 @@ class ContextService:
         else:
             logger.debug(f"Build context for '{types}'")
             primary = await self.search_repository.search(
-                types=types, after_date=since, limit=limit, offset=offset
+                entity_types=types, after_date=since, limit=limit, offset=offset
             )
 
         # Get type_id pairs for traversal
@@ -165,7 +165,7 @@ class ContextService:
                 from_id,
                 to_id,
                 relation_type,
-                content,
+                content_snippet as content,
                 category,
                 entity_id,
                 0 as depth,
@@ -189,7 +189,7 @@ class ContextService:
                 r.from_id,
                 r.to_id,
                 r.relation_type,
-                r.content,
+                r.content_snippet as content,
                 r.category,
                 r.entity_id,
                 cg.depth + 1,
@@ -218,7 +218,7 @@ class ContextService:
                 e.from_id,
                 e.to_id,
                 e.relation_type,
-                e.content,
+                e.content_snippet as content,
                 e.category,
                 e.entity_id,
                 cg.depth + 1,  -- Increment depth for entities
