@@ -1,4 +1,4 @@
-from basic_memory.config import config
+import os
 
 # set config.env to "test" for pytest to prevent logging to file in utils.setup_logging()
-config.env = "test"
+os.environ["BASIC_MEMORY_ENV"] = "test"
