@@ -1,16 +1,19 @@
 """Tests for EntityService."""
 
 from pathlib import Path
+from textwrap import dedent
 
 import pytest
 import yaml
 
+from basic_memory.config import ProjectConfig
+from basic_memory.markdown import EntityParser
 from basic_memory.models import Entity as EntityModel
 from basic_memory.repository import EntityRepository
 from basic_memory.schemas import Entity as EntitySchema
 from basic_memory.services import FileService
 from basic_memory.services.entity_service import EntityService
-from basic_memory.services.exceptions import EntityNotFoundError, EntityCreationError
+from basic_memory.services.exceptions import EntityCreationError, EntityNotFoundError
 from basic_memory.utils import generate_permalink
 
 
@@ -184,6 +187,25 @@ async def test_delete_entity_success(entity_service: EntityService):
         await entity_service.get_by_permalink(entity_data.permalink)
 
 
+@pytest.mark.asyncio
+async def test_delete_entity_by_id(entity_service: EntityService):
+    """Test successful entity deletion."""
+    entity_data = EntitySchema(
+        title="TestEntity",
+        folder="test",
+        entity_type="test",
+    )
+    created = await entity_service.create_entity(entity_data)
+
+    # Act using permalink
+    result = await entity_service.delete_entity(created.id)
+
+    # Assert
+    assert result is True
+    with pytest.raises(EntityNotFoundError):
+        await entity_service.get_by_permalink(entity_data.permalink)
+
+
 @pytest.mark.asyncio
 async def test_get_entity_by_permalink_not_found(entity_service: EntityService):
     """Test handling of non-existent entity retrieval."""
@@ -241,7 +263,7 @@ async def test_get_entities_by_permalinks(entity_service: EntityService):
 
 
 @pytest.mark.asyncio
-async def test_oget_entities_empty_input(entity_service: EntityService):
+async def test_get_entities_empty_input(entity_service: EntityService):
     """Test opening nodes with empty path ID list."""
     found = await entity_service.get_entities_by_permalinks([])
     assert len(found) == 0
@@ -356,21 +378,25 @@ async def test_create_or_update_existing(entity_service: EntityService, file_ser
 
 @pytest.mark.asyncio
 async def test_create_with_content(entity_service: EntityService, file_service: FileService):
-    content = """---
-permalink: git-workflow-guide
----
-# Git Workflow Guide
+    # contains frontmatter
+    content = dedent(
+        """
+        ---
+        permalink: git-workflow-guide
+        ---
+        # Git Workflow Guide
+                
+        A guide to our [[Git]] workflow. This uses some ideas from [[Trunk Based Development]].
         
-A guide to our [[Git]] workflow. This uses some ideas from [[Trunk Based Development]].
-
-## Best Practices
-Use branches effectively:
-- [design] Keep feature branches short-lived #git #workflow (Reduces merge conflicts)
-- implements [[Branch Strategy]] (Our standard workflow)
-
-## Common Commands
-See the [[Git Cheat Sheet]] for reference.
-"""
+        ## Best Practices
+        Use branches effectively:
+        - [design] Keep feature branches short-lived #git #workflow (Reduces merge conflicts)
+        - implements [[Branch Strategy]] (Our standard workflow)
+        
+        ## Common Commands
+        See the [[Git Cheat Sheet]] for reference.
+        """
+    )
 
     # Create test entity
     entity, created = await entity_service.create_or_update_entity(
@@ -409,20 +435,29 @@ See the [[Git Cheat Sheet]] for reference.
     file_path = file_service.get_entity_path(entity)
     file_content, _ = await file_service.read_file(file_path)
 
-    # assert content is in file
-    assert content.strip() in file_content
+    # assert file
+    # note the permalink value is corrected
+    expected = dedent("""
+        ---
+        title: Git Workflow Guide
+        type: test
+        permalink: test/git-workflow-guide
+        ---
+        
+        # Git Workflow Guide
+                
+        A guide to our [[Git]] workflow. This uses some ideas from [[Trunk Based Development]].
+        
+        ## Best Practices
+        Use branches effectively:
+        - [design] Keep feature branches short-lived #git #workflow (Reduces merge conflicts)
+        - implements [[Branch Strategy]] (Our standard workflow)
+        
+        ## Common Commands
+        See the [[Git Cheat Sheet]] for reference.
 
-    # assert frontmatter
-    assert (
-        """
----
-title: Git Workflow Guide
-type: test
-permalink: test/git-workflow-guide
----    
-    """.strip()
-        in file_content
-    )
+        """).strip()
+    assert expected == file_content
 
 
 @pytest.mark.asyncio
@@ -450,23 +485,45 @@ async def test_update_with_content(entity_service: EntityService, file_service:
     file_content, _ = await file_service.read_file(file_path)
 
     # assert content is in file
-    assert content.strip() in file_content
+    assert (
+        dedent(
+            """
+            ---
+            title: Git Workflow Guide
+            type: test
+            permalink: test/git-workflow-guide
+            ---
+            
+            # Git Workflow Guide
+            """
+        ).strip()
+        == file_content
+    )
 
     # now update the content
-    update_content = """# Git Workflow Guide
+    update_content = dedent(
+        """
+        ---
+        title: Git Workflow Guide
+        type: test
+        permalink: test/git-workflow-guide
+        ---
+        
+        # Git Workflow Guide
+        
+        A guide to our [[Git]] workflow. This uses some ideas from [[Trunk Based Development]].
+        
+        ## Best Practices
+        Use branches effectively:
+        - [design] Keep feature branches short-lived #git #workflow (Reduces merge conflicts)
+        - implements [[Branch Strategy]] (Our standard workflow)
+        
+        ## Common Commands
+        See the [[Git Cheat Sheet]] for reference.
+        """
+    ).strip()
 
-A guide to our [[Git]] workflow. This uses some ideas from [[Trunk Based Development]].
-
-## Best Practices
-Use branches effectively:
-- [design] Keep feature branches short-lived #git #workflow (Reduces merge conflicts)
-- implements [[Branch Strategy]] (Our standard workflow)
-
-## Common Commands
-See the [[Git Cheat Sheet]] for reference.
-"""
-
-    # Create test entity
+    # update entity
     entity, created = await entity_service.create_or_update_entity(
         EntitySchema(
             title="Git Workflow Guide",
@@ -501,4 +558,34 @@ See the [[Git Cheat Sheet]] for reference.
     file_content, _ = await file_service.read_file(file_path)
 
     # assert content is in file
-    assert update_content.strip() in file_content
+    assert update_content.strip() == file_content
+
+
+@pytest.mark.asyncio
+async def test_create_with_no_frontmatter(
+    test_config: ProjectConfig,
+    entity_parser: EntityParser,
+    entity_service: EntityService,
+    file_service: FileService,
+):
+    # contains no frontmatter
+    content = "# Git Workflow Guide"
+    file_path = Path("test/Git Workflow Guide.md")
+    full_path = test_config.home / file_path
+
+    await file_service.write_file(Path(full_path), content)
+
+    entity_markdown = await entity_parser.parse_file(full_path)
+    created = await entity_service.create_entity_from_markdown(file_path, entity_markdown)
+    file_content, _ = await file_service.read_file(created.file_path)
+
+    assert str(file_path) == str(created.file_path)
+    assert created.title == "Git Workflow Guide"
+    assert created.entity_type == "note"
+    assert created.permalink is None
+
+    # assert file
+    expected = dedent("""
+        # Git Workflow Guide
+        """).strip()
+    assert expected == file_content
