@@ -3,8 +3,10 @@
 import asyncio
 from datetime import datetime, timezone
 from pathlib import Path
+from textwrap import dedent
 
 import pytest
+import pytest_asyncio
 
 from basic_memory.config import ProjectConfig
 from basic_memory.models import Entity
@@ -48,7 +50,7 @@ type: knowledge
 
     # Verify forward reference
     source = await entity_service.get_by_permalink("source")
-    assert len(source.relations) == 2
+    assert len(source.relations) == 1
     assert source.relations[0].to_id is None
     assert source.relations[0].to_name == "target-doc"
 
@@ -68,13 +70,13 @@ Target content
     # Verify reference is now resolved
     source = await entity_service.get_by_permalink("source")
     target = await entity_service.get_by_permalink("target-doc")
-    assert len(source.relations) == 2
+    assert len(source.relations) == 1
     assert source.relations[0].to_id == target.id
     assert source.relations[0].to_name == target.title
 
 
 @pytest.mark.asyncio
-async def test_sync_knowledge(
+async def test_sync(
     sync_service: SyncService, test_config: ProjectConfig, entity_service: EntityService
 ):
     """Test basic knowledge sync functionality."""
@@ -130,10 +132,29 @@ A test concept.
     # with forward link
     entity = await entity_service.get_by_permalink(test_concept.permalink)
     relations = entity.relations
-    assert len(relations) == 1
+    assert len(relations) == 1, "Expected 1 relation for entity"
     assert relations[0].to_name == "concept/other"
 
 
+@pytest.mark.asyncio
+async def test_sync_hidden_file(
+    sync_service: SyncService, test_config: ProjectConfig, entity_service: EntityService
+):
+    """Test basic knowledge sync functionality."""
+    # Create test files
+    project_dir = test_config.home
+
+    # hidden file
+    await create_test_file(project_dir / "concept/.hidden.md", "hidden")
+
+    # Run sync
+    await sync_service.sync(test_config.home)
+
+    # Verify results
+    entities = await entity_service.repository.find_all()
+    assert len(entities) == 0
+
+
 @pytest.mark.asyncio
 async def test_sync_entity_with_nonexistent_relations(
     sync_service: SyncService, test_config: ProjectConfig
@@ -470,8 +491,12 @@ modified: 2024-01-01
     # Verify final state
     doc = await sync_service.entity_service.repository.get_by_permalink("changing")
     assert doc is not None
-    # File should have a checksum, even if it's from either version
-    assert doc.checksum is not None
+
+    # if we failed in the middle of a sync, the next one should fix it.
+    if doc.checksum is None:
+        await sync_service.sync(test_config.home)
+        doc = await sync_service.entity_service.repository.get_by_permalink("changing")
+        assert doc.checksum is not None
 
 
 @pytest.mark.asyncio
@@ -529,7 +554,7 @@ async def test_handle_entity_deletion(
 
     root_entity = test_graph["root"]
     # Delete the entity
-    await sync_service.handle_entity_deletion(root_entity.file_path)
+    await sync_service.handle_delete(root_entity.file_path)
 
     # Verify entity is gone from db
     assert await entity_repository.get_by_permalink(root_entity.permalink) is None
@@ -740,8 +765,28 @@ async def test_sync_permalink_resolved_on_update(
 
     one_file = project_dir / "one.md"
     two_file = project_dir / "two.md"
-    await create_test_file(one_file)
-    await create_test_file(two_file)
+    await create_test_file(
+        one_file,
+        content=dedent(
+            """
+            ---
+            permalink: one
+            ---
+            test content
+            """
+        ),
+    )
+    await create_test_file(
+        two_file,
+        content=dedent(
+            """
+            ---
+            permalink: two
+            ---
+            test content
+            """
+        ),
+    )
 
     # Run sync
     await sync_service.sync(test_config.home)
@@ -796,7 +841,7 @@ test content
 
 
 @pytest.mark.asyncio
-async def test_sync_duplicate_observations(
+async def test_sync_permalink_not_created_if_no_frontmatter(
     sync_service: SyncService,
     test_config: ProjectConfig,
     file_service: FileService,
@@ -804,16 +849,209 @@ async def test_sync_duplicate_observations(
     """Test that sync resolves permalink conflicts on update."""
     project_dir = test_config.home
 
-    content = """
+    file = project_dir / "one.md"
+    await create_test_file(file)
+
+    # Run sync
+    await sync_service.sync(test_config.home)
+
+    # Check permalink not created
+    file_content, _ = await file_service.read_file(file)
+    assert "permalink:" not in file_content
+
+
+@pytest_asyncio.fixture
+def test_config_update_permamlinks_on_move(tmp_path) -> ProjectConfig:
+    """Test configuration using in-memory DB."""
+    config = ProjectConfig(
+        project="test-project",
+        update_permalinks_on_move=True,
+    )
+    config.home = tmp_path
+
+    (tmp_path / config.home.name).mkdir(parents=True, exist_ok=True)
+    return config
+
+
+@pytest.mark.asyncio
+async def test_sync_permalink_updated_on_move(
+    test_config_update_permamlinks_on_move: ProjectConfig,
+    sync_service: SyncService,
+    file_service: FileService,
+):
+    """Test that we update a permalink on a file move if set in config ."""
+    test_config = test_config_update_permamlinks_on_move
+    project_dir = test_config.home
+    sync_service.config = test_config
+
+    # Create initial file
+    content = dedent(
+        """
+        ---
+        type: knowledge
+        ---
+        # Test Move
+        Content for move test
+        """
+    )
+
+    old_path = project_dir / "old" / "test_move.md"
+    old_path.parent.mkdir(parents=True)
+    await create_test_file(old_path, content)
+
+    # Initial sync
+    await sync_service.sync(test_config.home)
+
+    # verify permalink
+    old_content, _ = await file_service.read_file(old_path)
+    assert "permalink: old/test-move" in old_content
+
+    # Move the file
+    new_path = project_dir / "new" / "moved_file.md"
+    new_path.parent.mkdir(parents=True)
+    old_path.rename(new_path)
+
+    # Sync again
+    await sync_service.sync(test_config.home)
+
+    file_content, _ = await file_service.read_file(new_path)
+    assert "permalink: new/moved-file" in file_content
+
+
+@pytest.mark.asyncio
+async def test_sync_non_markdown_files(sync_service, test_config, test_files):
+    """Test syncing non-markdown files."""
+    report = await sync_service.sync(test_config.home)
+    assert report.total == 2
+
+    # Check files were detected
+    assert test_files["pdf"].name in [f for f in report.new]
+    assert test_files["image"].name in [f for f in report.new]
+
+    # Verify entities were created
+    pdf_entity = await sync_service.entity_repository.get_by_file_path(str(test_files["pdf"].name))
+    assert pdf_entity is not None, "PDF entity should have been created"
+    assert pdf_entity.content_type == "application/pdf"
+
+    image_entity = await sync_service.entity_repository.get_by_file_path(
+        str(test_files["image"].name)
+    )
+    assert image_entity.content_type == "image/png"
+
+
+@pytest.mark.asyncio
+async def test_sync_non_markdown_files_modified(
+    sync_service, test_config, test_files, file_service
+):
+    """Test syncing non-markdown files."""
+    report = await sync_service.sync(test_config.home)
+    assert report.total == 2
+
+    # Check files were detected
+    assert test_files["pdf"].name in [f for f in report.new]
+    assert test_files["image"].name in [f for f in report.new]
+
+    test_files["pdf"].write_text("New content")
+    test_files["image"].write_text("New content")
+
+    report = await sync_service.sync(test_config.home)
+    assert len(report.modified) == 2
+
+    pdf_file_content, pdf_checksum = await file_service.read_file(test_files["pdf"].name)
+    image_file_content, img_checksum = await file_service.read_file(test_files["image"].name)
+
+    pdf_entity = await sync_service.entity_repository.get_by_file_path(str(test_files["pdf"].name))
+    image_entity = await sync_service.entity_repository.get_by_file_path(
+        str(test_files["image"].name)
+    )
+
+    assert pdf_entity.checksum == pdf_checksum
+    assert image_entity.checksum == img_checksum
+
+
+@pytest.mark.asyncio
+async def test_sync_non_markdown_files_move(sync_service, test_config, test_files):
+    """Test syncing non-markdown files updates permalink"""
+    report = await sync_service.sync(test_config.home)
+    assert report.total == 2
+
+    # Check files were detected
+    assert test_files["pdf"].name in [f for f in report.new]
+    assert test_files["image"].name in [f for f in report.new]
+
+    test_files["pdf"].rename(test_config.home / "moved_pdf.pdf")
+    report2 = await sync_service.sync(test_config.home)
+    assert len(report2.moves) == 1
+
+    # Verify entity is updated
+    pdf_entity = await sync_service.entity_repository.get_by_file_path("moved_pdf.pdf")
+    assert pdf_entity is not None
+    assert pdf_entity.permalink is None
+
+
+@pytest.mark.asyncio
+async def test_sync_non_markdown_files_deleted(sync_service, test_config, test_files):
+    """Test syncing non-markdown files updates permalink"""
+    report = await sync_service.sync(test_config.home)
+    assert report.total == 2
+
+    # Check files were detected
+    assert test_files["pdf"].name in [f for f in report.new]
+    assert test_files["image"].name in [f for f in report.new]
+
+    test_files["pdf"].unlink()
+    report2 = await sync_service.sync(test_config.home)
+    assert len(report2.deleted) == 1
+
+    # Verify entity is deleted
+    pdf_entity = await sync_service.entity_repository.get_by_file_path("moved_pdf.pdf")
+    assert pdf_entity is None
+
+
+@pytest.mark.asyncio
+async def test_sync_non_markdown_files_move_with_delete(
+    sync_service, test_config, test_files, file_service
+):
+    """Test syncing non-markdown files handles file deletes and renames during sync"""
+
+    # Create initial files
+    await create_test_file(test_config.home / "doc.pdf", "content1")
+    await create_test_file(test_config.home / "other/doc-1.pdf", "content2")
+
+    # Initial sync
+    await sync_service.sync(test_config.home)
+
+    # First move/delete the original file to make way for the move
+    (test_config.home / "doc.pdf").unlink()
+    (test_config.home / "other/doc-1.pdf").rename(test_config.home / "doc.pdf")
+
+    # Sync again
+    await sync_service.sync(test_config.home)
+
+    # Verify the changes
+    moved_entity = await sync_service.entity_repository.get_by_file_path("doc.pdf")
+    assert moved_entity is not None
+    assert moved_entity.permalink is None
+
+    file_content, _ = await file_service.read_file("doc.pdf")
+    assert "content2" in file_content
+
+
+@pytest.mark.asyncio
+async def test_sync_relation_to_non_markdown_file(
+    sync_service: SyncService, test_config: ProjectConfig, file_service: FileService, test_files
+):
+    """Test that sync resolves permalink conflicts on update."""
+    project_dir = test_config.home
+
+    content = f"""
 ---
 title: a note
 type: note
 tags: []
 ---
 
-test content
-
-- [note] one observation
+- relates_to [[{test_files["pdf"].name}]]
 """
 
     note_file = project_dir / "note.md"
@@ -825,16 +1063,14 @@ test content
     # Check permalinks
     file_one_content, _ = await file_service.read_file(note_file)
     assert (
-        """---
+        f"""---
 title: a note
 type: note
 tags: []
 permalink: note
 ---
 
-test content
-
-- [note] one observation
+- relates_to [[{test_files["pdf"].name}]]
 """.strip()
         == file_one_content
     )
